#
# spec file for package perl-Domain-PublicSuffix
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Domain-PublicSuffix
Name:           perl-Domain-PublicSuffix
Version:        0.200.0
Release:        2.2
%define cpan_version 0.20
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Parse a domain down to root
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/N/NM/NMELNICK/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Class::Accessor::Fast)
BuildRequires:  perl(Net::IDN::Encode) >= 2.401
BuildRequires:  perl(Test::More) >= 0.88
Requires:       perl(Class::Accessor::Fast)
Requires:       perl(Net::IDN::Encode) >= 2.401
Requires:       perl(Test::More) >= 0.88
Provides:       perl(Domain::PublicSuffix) = 0.200.0
Provides:       perl(Domain::PublicSuffix::Default) = 0.200.0
%undefine       __perllib_provides
%{perl_requires}

%description
This module utilizes the "effective_tld_names.dat" provided by Mozilla as a
way to effectively reduce a fully qualified domain name down to the
absolute root. The Mozilla PublicSuffix file is an open source, fully
documented format that shows absolute root TLDs, primarily for Mozilla's
browser products to be able to determine how far a cookie's security
boundaries go.

This module will attempt to search etc directories in
/usr/share/publicsuffix, /usr, /usr/local, and /opt/local for the
effective_tld_names.dat file. If a file is not found, a default file is
loaded from Domain::PublicSuffix::Default, which is current at the time of
the module's release. You can override the data file path by giving the
new() method a 'data_file' argument.

When creating a new PublicSuffix object, the module will load the data file
as specified, and use the internal structure to parse each domain sent to
the get_root_domain method. To re-parse the file, you must destroy and
create a new object, or execute the _parse_data_file method directly,
though that is not recommended.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README README.md util
%license LICENSE

%changelog
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Thu Aug 24 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.20
  see /usr/share/doc/packages/perl-Domain-PublicSuffix/Changes
  0.20    2023-08-23 13:55 GMT
  - Refresh PublicSuffix list
* Fri Jan 29 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.19
  see /usr/share/doc/packages/perl-Domain-PublicSuffix/Changes
  0.19    2021-01-28 17:03 GMT
  - Refresh PublicSuffix list
* Tue Apr 14 2020 <timueller+perl@suse.de>
- updated to 0.17
  see /usr/share/doc/packages/perl-Domain-PublicSuffix/Changes
  0.17    2020-04-13 14:08 GMT
  - Refresh PublicSuffix list
  - Fix documentation regarding what tld() will return
  - Add Default updater
  - Fix warnings in tests
* Mon Oct 21 2019 <timueller+perl@suse.de>
- updated to 0.16
  see /usr/share/doc/packages/perl-Domain-PublicSuffix/Changes
  0.16    2019-10-18 20:00 GMT
  - Refresh PublicSuffix list
  - Add publicsuffix.org unit tests
  - Force lower case on ASCII domains
  - Rewrite suffix parser to both more closely match publicsuffix intentions,
    as well as reduce needless complexity, also solving a comment on issue
    [#3]
  0.15    2019-04-23 20:00 GMT
  - Refresh PublicSuffix list
  - Merged pull request from Gavin Carr to explicitly open a file with UTF-8
    encoding
  - Bump Net::IDN::Encode requirement to 2.401 to avoid unicode issues
  - (#3) Provide a tld and suffix even with asking get_root_domain for a valid
    suffix that is not a valid domain. Will still report 'Domain not valid',
    but ->suffix and ->tld will resolve.
  - Make sure that the error condition from get_root_domain still throws when
    a root domain is already fired, but that it still returns.
* Mon Sep 17 2018 Dirk Stoecker <opensuse@dstoecker.de>
- first version
